@@ -1,10 +1,11 @@
-from __future__ import print_function, absolute_import, division
-
-
 class CudaDriverError(Exception):
     pass
 
 
+class CudaRuntimeError(Exception):
+    pass
+
+
 class CudaSupportError(ImportError):
     pass
 
