@@ -11,7 +11,7 @@ class TestDeprecation(unittest.TestCase):
         self.assertEqual(len(warnings), 1)
         self.assertEqual(warnings[0].category, category)
         self.assertIn(expected_str, str(warnings[0].message))
-        self.assertIn("https://numba.pydata.org", str(warnings[0].message))
+        self.assertIn("https://numba.readthedocs.io", str(warnings[0].message))
 
     def test_jitfallback(self):
         # tests that @jit falling back to object mode raises a
@@ -52,7 +52,7 @@ class TestDeprecation(unittest.TestCase):
                 self.assertIn(msg, warn_msg)
                 msg = ("\'reflected %s\' found for argument" % container)
                 self.assertIn(msg, warn_msg)
-                self.assertIn("https://numba.pydata.org", warn_msg)
+                self.assertIn("https://numba.readthedocs.io", warn_msg)
 
 
 if __name__ == '__main__':
