@@ -3,10 +3,10 @@ from numba.core.compiler import compile_isolated, Flags
 from numba.core import types, utils
 
 enable_pyobj_flags = Flags()
-enable_pyobj_flags.set("enable_pyobject")
+enable_pyobj_flags.enable_pyobject = True
 
 force_pyobj_flags = Flags()
-force_pyobj_flags.set("force_pyobject")
+force_pyobj_flags.force_pyobject = True
 
 
 def is_in_mandelbrot(c):
