@@ -3,7 +3,7 @@ from numba.core.compiler import compile_isolated, Flags
 from numba.core import types
 
 enable_pyobj_flags = Flags()
-enable_pyobj_flags.set("enable_pyobject")
+enable_pyobj_flags.enable_pyobject = True
 
 no_pyobj_flags = Flags()
 
